@@ -83,13 +83,13 @@ class Time:
                 self.shifts = np.random.permutation(self.shifts)
 
 
-class LoaderOfBalancedAndClassDirectoryDataset:
+class LoaderOfImageDatasetWithBalancedClassesAndClassDirectories:
 
     def __init__(
             self, directory_root, level_classes, n_levels_directories=None,
             conditions_directories=None, batch_size=None, n_batches=None,
             shuffle=False, time=None, transforms=None, device=None,
-            return_combinations_eb=False, return_directories_eb=False):
+            return_combinations_eb=False):
 
         self.directory_root = directory_root
         self.level_classes = level_classes
@@ -114,8 +114,6 @@ class LoaderOfBalancedAndClassDirectoryDataset:
 
         self.return_combinations_eb = return_combinations_eb
 
-        self.return_directories_eb = return_directories_eb
-
         self.conditions_directories_names = [None] * self.L  # type: list
         self.n_conditions_directories = [None] * self.L  # type: list
         self.conditions_directories = [None] * self.L  # type: list
@@ -198,11 +196,6 @@ class LoaderOfBalancedAndClassDirectoryDataset:
 
         self.combinations_eb = None
 
-        if self.return_directories_eb:
-            self.directories_eb = [None] * self.batch_size  # type: list
-        else:
-            self.directories_eb = None
-
         combination_directory_str_0 = [self.conditions_directories_names[l][0] for l in range(self.L)]
         directory_0 = os.path.join(self.directory_root, *combination_directory_str_0)
         image_0 = PIL.Image.open(directory_0)
@@ -239,70 +232,25 @@ class LoaderOfBalancedAndClassDirectoryDataset:
         # self.n_batches = 3
         if self.return_combinations_eb:
 
-            if self.return_directories_eb:
-
-                for b in range(self.n_batches):
-                    self.labels_eb = self.labels[self.batches_indexes[b]]
-
-                    self.combinations_eb = self.combinations_directories[self.batches_indexes[b], :]
-                    # batch_size_eb = batches_indexes_e.shape[0]
-                    for i in range(self.batch_size):
-                        combination_directory_ebi = self.combinations_eb[i, :]
-                        combination_directory_str_ebi = [
-                            self.conditions_directories_names[l][combination_directory_ebi[l]]
-                            for l in range(self.L)]
-                        directory_ebi = os.path.join(self.directory_root, *combination_directory_str_ebi)
-
-                        self.directories_eb[i] = directory_ebi
-
-                        self.indexes_batch[0] = i
-
-                        image_ebi = PIL.Image.open(directory_ebi)
-                        self.tensor_batch[tuple(self.indexes_batch)] = self.transforms(image_ebi)
-
-                    yield [self.tensor_batch, self.labels_eb, self.combinations_eb, self.directories_eb]
-            else:
-
-                for b in range(self.n_batches):
-                    self.labels_eb = self.labels[self.batches_indexes[b]]
-
-                    self.combinations_eb = self.combinations_directories[self.batches_indexes[b], :]
-                    # batch_size_eb = batches_indexes_e.shape[0]
-                    for i in range(self.batch_size):
-                        combination_directory_ebi = self.combinations_eb[i, :]
-                        combination_directory_str_ebi = [
-                            self.conditions_directories_names[l][combination_directory_ebi[l]]
-                            for l in range(self.L)]
-
-                        directory_ebi = os.path.join(self.directory_root, *combination_directory_str_ebi)
-
-                        self.indexes_batch[0] = i
-
-                        image_ebi = PIL.Image.open(directory_ebi)
-                        self.tensor_batch[tuple(self.indexes_batch)] = self.transforms(image_ebi)
-
-                    yield [self.tensor_batch, self.labels_eb, self.combinations_eb]
-
-        elif self.return_directories_eb:
-
             for b in range(self.n_batches):
                 self.labels_eb = self.labels[self.batches_indexes[b]]
+
+                self.combinations_eb = self.combinations_directories[self.batches_indexes[b], :]
                 # batch_size_eb = batches_indexes_e.shape[0]
                 for i in range(self.batch_size):
-                    combination_directory_ebi = self.combinations_directories[self.batches_indexes[b][i], :]
+                    combination_directory_ebi = self.combinations_eb[i, :]
                     combination_directory_str_ebi = [
                         self.conditions_directories_names[l][combination_directory_ebi[l]]
                         for l in range(self.L)]
-                    directory_ebi = os.path.join(self.directory_root, *combination_directory_str_ebi)
 
-                    self.directories_eb[i] = directory_ebi
+                    directory_ebi = os.path.join(self.directory_root, *combination_directory_str_ebi)
 
                     self.indexes_batch[0] = i
 
                     image_ebi = PIL.Image.open(directory_ebi)
                     self.tensor_batch[tuple(self.indexes_batch)] = self.transforms(image_ebi)
 
-                yield [self.tensor_batch, self.labels_eb, self.directories_eb]
+                yield [self.tensor_batch, self.labels_eb, self.combinations_eb]
 
         else:
 
@@ -323,8 +271,8 @@ class LoaderOfBalancedAndClassDirectoryDataset:
                 yield [self.tensor_batch, self.labels_eb]
 
 
-def train_early_stop(
-        model, loader, criterion, optimizer, scheduler, I=10, directory_outputs=''):
+def train_classifier_with_early_stop(
+        model, loader, criterion, optimizer, scheduler, I=20, directory_outputs=''):
 
     # timer = cc_clock.Timer()
     cc_timer = cc_clock.Timer()
@@ -546,7 +494,7 @@ def train_early_stop(
 
 
 def test_classifier(model, criterion, loader):
-    loader = LoaderOfBalancedAndClassDirectoryDataset()
+
     # timer = cc_clock.Timer()
     cc_timer = cc_clock.Timer()
 
@@ -576,7 +524,7 @@ def test_classifier(model, criterion, loader):
 
     n_decimals_for_printing = 6
 
-    if model2.training:
+    if model.training:
         model.eval()  # Set model to evaluate mode
 
     torch.set_grad_enabled(False)
